@@ -16,6 +16,7 @@ sns.set_style('whitegrid')
 
 from ml_processor.configuration import config
 
+# <<<<<<<<<<<<<<<<<<<<<<<<>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
 class data_prep:
 
     """
@@ -81,15 +82,15 @@ class data_prep:
 
         """
 
-        start = time.process_time()
+        start = int(time.time())
         
         X = self.data[self.categories].values
         
-        self.encoder = OneHotEncoder(handle_unknown='ignore', drop=drop, sparse=False)
+        self.encoder = OneHotEncoder(drop=drop, sparse=False)
         
         self.encoder = self.encoder.fit(X)
 
-        end = time.process_time()
+        end = int(time.time())
 
         if verbose:
             self.log.info('OneHotEncoder created')
@@ -131,11 +132,11 @@ class data_prep:
         if not self.encoder:
             self.create_encoder()
 
-        start = time.process_time()
+        start = int(time.time())
 
         X_encoded = self.encoder.transform(X)
 
-        end = time.process_time()
+        end = int(time.time())
 
         df_encoded = pd.DataFrame(X_encoded, columns=self.encoder.get_feature_names(self.categories))
 
@@ -195,7 +196,7 @@ class data_prep:
         
         """ 
 
-        start = time.process_time()
+        start = int(time.time())
 
         X = self.data[self.features]
         
@@ -211,7 +212,7 @@ class data_prep:
         
         binning_process.fit(X, y)
 
-        end = time.process_time()
+        end = int(time.time())
 
         if verbose:
             self.log.info(f'Binning processor created')
@@ -256,7 +257,7 @@ class data_prep:
         
         return woe_table
     
-    def get_var_bins(self, var):
+    def get_var_bins(self, var, ax, plot_type="WoE"):
 
         """
 
@@ -267,12 +268,19 @@ class data_prep:
         
         var : string 
             Name of variable for which to show binning tables
+
+        ax : matplotlib.axes
+            Axes to plot on.
+
+        plot_type : string (default="WoE", options=[""WoE", "event_rate"])
+            Whether to plot WoE or event rate per bin
             
         Returns
         -------   
         plot : matplotlib plot
         
         """
+
         if not self.binning_process:
             self.woe_bins()  
             
@@ -280,67 +288,74 @@ class data_prep:
 
         table = self.optb.binning_table.build()
         
-        table = table[~table['Bin'].isin(['Special','Missing'])]
-        
         table.drop(['Totals'], inplace=True)
-        
+
         table['WoE'] = pd.to_numeric(table['WoE'])
-        
+
+        table = table.query("abs(WoE)>0")
+
         table['Bin'] = table['Bin'].astype('string')
         
-        fig, ax = plt.subplots(1,2,figsize=(12,4))
-        
-        for i in range(2):
-        
-            if i==0:
-                
-                sns.barplot(x='Bin', y='WoE', data=table, ax=ax[i], color='deepskyblue')
-                
-                ax[i].set_title('WoE per bins created \nfor {}'.format(var), fontsize = 12, fontweight='bold', fontname='Georgia')
-                
-                ax[i].tick_params(axis='both', which='major', labelsize=10)
-                
-                ax[i].tick_params(axis='x', which='major', rotation=90)
-                
-                ax[i].set_xlabel('Bin', fontsize=10)
-                
-                ax[i].set_ylabel('WoE', fontsize=10)
-                
-                plt.xlabel('Bin', fontsize=10)
-            
-            else:
-                
-                ax[i].bar(table['Bin'], table['Event'], color='#ff2e63', label='Event')
-                
-                ax[i].bar(table['Bin'], table['Non-event'], bottom=table['Event'], color='#48d1cc', label='Non-event')
-                
-                ax[i].tick_params(axis='both', which='both', labelsize=10)
-                
-                ax[i].tick_params(axis='x', which='major', rotation=90)
-                
-                ax[i].legend(frameon=False, fontsize=8)
-                
-                ax[i].set_ylabel('Count', fontsize=10)
-                
-                table['Bin'] = table['Bin'].astype('category')
-                
-                ax2 = ax[i].twinx()
-                
-                ax2.plot(table['Bin'], table['Event rate'], color='k', marker='o', label='event rate')
-                
-                ax2.set_yticklabels(['{:.0%}'.format(x) for x in ax2.get_yticks()])
-                
-                ax2.set_ylabel('Event rate', fontsize=10)
+        if plot_type == "WoE":
 
-                ax2.grid(False)
-                
-                plt.title('Event rate per bin \nfor {}'.format(var), fontname='Georgia', fontsize=12, fontweight='bold')
-                
-                plt.xlabel('Bin', fontsize=10)
+            sns.barplot(x='Bin', y='WoE', data=table, ax=ax, color='deepskyblue')
+
+            ax.set_title('WoE per bins created \nfor {}'.format(var), fontsize = 12, fontweight='bold', fontname='Georgia')
+
+            ax.tick_params(axis='both', which='major', labelsize=10)
+
+            ax.tick_params(axis='x', which='major', rotation=90)
+
+            ax.set_xlabel('Bin', fontsize=10)
+
+            ax.set_ylabel('WoE', fontsize=10)
+
+            ax.set_xlabel('Bin', fontsize=10)
+
+            ax.spines["top"].set_visible(False)
+            ax.spines["right"].set_visible(False)
+            ax.spines["left"].set_visible(False)
         
-        plt.subplots_adjust(wspace=0.4)
-        
-        plt.show()
+        else:
+            
+            ax.bar(table['Bin'], table['Event'], color='#ff2e63', label='Event')
+            
+            ax.bar(table['Bin'], table['Non-event'], bottom=table['Event'], color='#48d1cc', label='Non-event')
+            
+            ax.tick_params(axis='both', which='both', labelsize=10)
+            
+            ax.tick_params(axis='x', which='major', rotation=90)
+            
+            ax.legend(frameon=False, fontsize=8)
+            
+            ax.set_ylabel('Count', fontsize=10)
+
+            ax.set_title('Event rate per bin \nfor {}'.format(var), fontname='Georgia', fontsize=12, fontweight='bold')
+            
+            ax.set_xlabel('Bin', fontsize=10)
+
+            ax.spines["top"].set_visible(False)
+            ax.spines["right"].set_visible(False)
+            ax.spines["left"].set_visible(False)
+
+            
+            table['Bin'] = table['Bin'].astype('category')
+            
+            ax2 = ax.twinx()
+            
+            ax2.plot(table['Bin'], table['Event rate'], color='k', marker='o', label='event rate')
+            
+            ax2.set_yticklabels(['{:.0%}'.format(x) for x in ax2.get_yticks()])
+            
+            ax2.set_ylabel('Event rate', fontsize=10)
+
+            ax2.grid(False)
+
+            ax2.tick_params(axis='y', which='both', right=False, left=False)
+
+            ax2.spines["top"].set_visible(False)
+            ax2.spines["right"].set_visible(False)
+            ax2.spines["left"].set_visible(False)
         
     def woe_transform(self, data=pd.DataFrame(), verbose=False):
 
@@ -371,7 +386,7 @@ class data_prep:
         if not self.binning_process:
             self.woe_bins()
 
-        start = time.process_time()
+        start = int(time.time())
         
         data_transf = data[self.features]
 
@@ -381,7 +396,7 @@ class data_prep:
         
         df_transformed['target'] = data[self.target].values  
 
-        end = time.process_time()
+        end = int(time.time())
 
         if verbose:
             self.log.info('Data transformation completed')
